@@ -1,6 +1,6 @@
 clm.newRho <-
   function(parent, y, X, weights, offset, tJac)
-### Set variables in rho: B1, B2, o1, o2, wts.
+### Set variables in rho: B1, B2, o1, o2 and wts.
 {
   rho <- new.env(parent = parent)
 
@@ -158,8 +158,8 @@ clm.fit.env <-
     } ## end convergence test
 
     ## Compute Newton step and update parameters
-    step <- .Call("La_dgesv", hessian, gradient, .Machine$double.eps,
-                  PACKAGE = "base") ## solve H*step = g for 'step'
+    ## step <- .Call("La_dgesv", hessian, gradient, .Machine$double.eps,
+    ##               PACKAGE = "base") ## solve H*step = g for 'step'
 ##     step <- try(.Call("La_dgesv", hessian, gradient, .Machine$double.eps,
 ##                       PACKAGE = "base"), silent=TRUE)
 ##     if(class(step) == "try-error") {
@@ -168,7 +168,8 @@ clm.fit.env <-
 ## identifiable")
 ##       break
 ##     }
-    step <- as.vector(step)
+    ## step <- as.vector(step)
+    step <- as.vector(solve(hessian, gradient))
     rho$par <- rho$par - stepFactor * step
     nllTry <- rho$clm.nll(rho)
     lineIter <- 0
@@ -210,7 +211,7 @@ clm.fit.env <-
                           format="e")))
         cat("\n")
       }
-      Trace(iter=i, stepFactor, nll,
+      Trace(iter=i+innerIter, stepFactor, nll,
             maxGrad, rho$par, first = FALSE)
     }
     ## Double stepFactor if needed:
@@ -244,14 +245,16 @@ clm.nll <- function(rho) { ## negative log-likelihood
   with(rho, {
     eta1 <- drop(B1 %*% par) + o1
     eta2 <- drop(B2 %*% par) + o2
-    fitted <- pfun(eta1) - pfun(eta2)
-    if(all(fitted > 0))
+  })
+### NOTE: getFitted is not found from within rho, so we have to
+### evalueate it outside of rho
+  rho$fitted <- getFittedC(rho$eta1, rho$eta2, rho$link)
+  if(all(rho$fitted > 0))
 ### NOTE: Need test here because some fitted <= 0 if thresholds are
 ### not ordered increasingly.
 ### It is assumed that 'all(is.finite(pr)) == TRUE' 
-      -sum(wts * log(fitted))
-    else Inf
-  })
+    -sum(rho$wts * log(rho$fitted))
+  else Inf
 }
 
 clm.grad <- function(rho) { ## gradient of the negative log-likelihood
